==> maven-shade-plugin_3.4.1.orig.tar.xz: maven-shade-plugin-maven-shade-plugin-3.4.1/src/main/java/org/apache/maven/plugins/shade/resource/properties/io/NoCloseOutputStream.java <==
package org.apache.maven.plugins.shade.resource.properties.io;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.IOException;
import java.io.OutputStream;

/**
 * Simple output stream replacing close call by a simpe flush.
 * Useful for output streams nesting streams (like jar output streams) and using a stream encoder.
 */
public class NoCloseOutputStream extends OutputStream
{
    private final OutputStream delegate;

    public NoCloseOutputStream( OutputStream delegate )
    {
        this.delegate = delegate;
    }

    @Override
    public void write( int b ) throws IOException
    {
        delegate.write( b );
    }

    @Override
    public void write( byte[] b ) throws IOException
    {
        delegate.write( b );
    }

    @Override
    public void write( byte[] b, int off, int len ) throws IOException
    {
        delegate.write( b, off, len );
    }

    @Override
    public void flush() throws IOException
    {
        delegate.flush();
    }

    @Override
    public void close() throws IOException
    {
        delegate.flush();
    }
}

==> maven-shade-plugin_3.6.0.orig.tar.xz: maven-shade-plugin-maven-shade-plugin-3.6.0/src/main/java/org/apache/maven/plugins/shade/resource/properties/io/NoCloseOutputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.shade.resource.properties.io;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Simple output stream replacing close call by a simple flush.
 * Useful for output streams nesting streams (like jar output streams) and using a stream encoder.
 */
public class NoCloseOutputStream extends OutputStream {
    private final OutputStream delegate;

    public NoCloseOutputStream(OutputStream delegate) {
        this.delegate = delegate;
    }

    @Override
    public void write(int b) throws IOException {
        delegate.write(b);
    }

    @Override
    public void write(byte[] b) throws IOException {
        delegate.write(b);
    }

    @Override
    public void write(byte[] b, int off, int len) throws IOException {
        delegate.write(b, off, len);
    }

    @Override
    public void flush() throws IOException {
        delegate.flush();
    }

    @Override
    public void close() throws IOException {
        delegate.flush();
    }
}
